@@ -1,6 +1,6 @@
 /**************************************************************************
  *  This file is part of QXmlEdit                                         *
- *  Copyright (C) 2011-2018 by Luca Bellonda and individual contributors  *
+ *  Copyright (C) 2011-2022 by Luca Bellonda and individual contributors  *
  *    as indicated in the AUTHORS file                                    *
  *  lbellonda _at_ gmail.com                                              *
  *                                                                        *
@@ -572,9 +572,10 @@ void Utils::TODO_THIS_RELEASE(const QString & inputMessage)
 {
     if(!inputMessage.isEmpty()) {
         if(isUnitTest) {
-            //fprintf(stderr, "TODO_THIS_RELEASE:%s\n", inputMessage.toLatin1().data());
+            fprintf(stderr, "TODO_THIS_RELEASE:%s\n", inputMessage.toLatin1().data());
         } else {
             fprintf(stderr, "TODO_THIS_RELEASE:%s\n", inputMessage.toLatin1().data());
+            fflush(stderr);
             //message(QString("TODO IN THIS RELEASE: %1").arg(inputMessage));
         }
     }
@@ -1291,3 +1292,17 @@ QString Utils::pathFromParent(Element* parent, const QString &tag)
     const QString path = basePath + "/" + tag;
     return path;
 }
+
+
+QString Utils::truncateString(const QString &msgText, const int maxLength)
+{
+    if(msgText.length() < maxLength) {
+        return msgText;
+    }
+    return msgText.left(maxLength) + "...";
+}
+
+QString Utils::truncateString(const QString &msgText)
+{
+    return truncateString(msgText, DEFAULT_TRUNCATE_STRING_LENGTH);
+}
